@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: apache_c.c,v 1.12 2004/10/23 11:49:57 rwmj Exp $
+ * $Id: apache_c.c,v 1.14 2004/11/19 16:42:25 rwmj Exp $
  */
 
 #include "config.h"
@@ -558,15 +558,24 @@ CAMLprim value
 mod_caml_request_send_http_header (value rv)
 {
   CAMLparam1 (rv);
-  request_rec *r = Request_rec_val (rv);
 #if APACHE2
   /* XXX do nothing in Apache 2.x? */
 #else
+  request_rec *r = Request_rec_val (rv);
   ap_send_http_header (r);
 #endif
   CAMLreturn (Val_unit);
 }
 
+CAMLprim value
+mod_caml_request_rflush (value rv)
+{
+  CAMLparam1 (rv);
+  request_rec *r = Request_rec_val (rv);
+  int i = ap_rflush (r);
+  CAMLreturn (Val_int (i));
+}
+
 CAMLprim value
 mod_caml_request_setup_client_block (value rv, value rp)
 {
@@ -733,10 +742,12 @@ mod_caml_get_server_config (value rv)
   CAMLparam1 (rv);
   CAMLlocal1 (config);
   request_rec *r = Request_rec_val (rv);
-  if (r->server && r->server->module_config)
-    config =
-      *(value *) ap_get_module_config (r->server->module_config, &caml_module);
-  else
+  if (r->server && r->server->module_config) {
+    void *c = ap_get_module_config (r->server->module_config, &caml_module);
+    if (c) config = *(value *) c;
+    else goto not_found;
+  } else
+  not_found:
     raise_not_found ();
   CAMLreturn (config);
 }
@@ -747,9 +758,12 @@ mod_caml_get_dir_config (value rv)
   CAMLparam1 (rv);
   CAMLlocal1 (config);
   request_rec *r = Request_rec_val (rv);
-  if (r->per_dir_config)
-    config = *(value *) ap_get_module_config (r->per_dir_config, &caml_module);
-  else
+  if (r->per_dir_config) {
+    void *c = ap_get_module_config (r->per_dir_config, &caml_module);
+    if (c) config = *(value *) c;
+    else goto not_found;
+  } else
+  not_found:
     raise_not_found ();
   CAMLreturn (config);
 }
