@@ -1,6 +1,6 @@
 (* ML part of mod_caml.
  * Copyright (C) 2003 Merjis Ltd.
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: mod_caml.ml,v 1.8 2004/11/19 16:42:25 rwmj Exp $
+ * $Id: mod_caml.ml,v 1.11 2004/12/14 12:51:54 ChriS Exp $
  *)
 
 (* Note a peculiarity of Apache: it runs all initialization TWICE. See this
@@ -56,8 +56,7 @@ let () =
     Dynlink.init ();
     Dynlink.allow_unsafe_modules true
   with
-    Dynlink.Error (e) ->
-      failwith (Dynlink.error_message e)
+    Dynlink.Error (e) -> failwith (Dynlink.error_message e)
 
 (*----- Configuration. -----*)
 
@@ -104,7 +103,8 @@ let merge_dir_config base add =
       { merged with post_read_request = add.post_read_request } else merged in
   let merged =
     if add.ocaml_bytecode_handler <> None then
-      { merged with ocaml_bytecode_handler = add.ocaml_bytecode_handler } else merged in
+      { merged with ocaml_bytecode_handler = add.ocaml_bytecode_handler }
+    else merged in
   merged
 
 let create_server_config s =
@@ -224,22 +224,24 @@ let reg_module_name = ref None
 (* Register the module's handler. *)
 let register_handler handler name =
   match !reg_module_name with
-    None -> failwith ("Mod_caml.register_handler call outside module " ^
-		      "initialization")
+  | None ->
+      failwith("Mod_caml.register_handler call outside module initialization")
   | Some module_name ->
       Hashtbl.replace reg_table (module_name ^ "." ^ name) handler
 
 (*----- Commands. -----*)
 
+(* CamlLoad [filename].  Preprend the ocaml standard library path
+   (ocamlc -where) if [filename] is relative. *)
 let cmd_load filename =
-  reg_module_name :=
-    Some (String.capitalize (Filename.chop_extension
-			       (Filename.basename filename)));
-  try
-    Dynlink.loadfile filename;
-  with
-    Dynlink.Error (e) ->
-      failwith (Dynlink.error_message e)
+  let filename =
+    if Filename.is_relative filename then
+      Filename.concat ocamllibdir filename
+    else filename in
+  reg_module_name := Some(String.capitalize(Filename.chop_extension
+					      (Filename.basename filename)));
+  try  Dynlink.loadfile filename;
+  with Dynlink.Error (e) -> failwith (Dynlink.error_message e)
 
 let cmd_translate_handler sconfig name =
   { sconfig with translate_handler = Some (Hashtbl.find reg_table name) }
@@ -308,6 +310,4 @@ let () =
     cmd_header_parser_handler;
   Callback.register "mod_caml_cmd_post_read_request_handler"
     cmd_post_read_request_handler;
-  Callback.register "mod_caml_cmd_handler" cmd_handler;
-
-  ()
+  Callback.register "mod_caml_cmd_handler" cmd_handler
